<template>
  <div class="bbsl-common-page">
    <!-- <div class="bbsl-table-search">
      <el-form v-model="queryParam" :inline="true">
        <el-form-item label="车牌号">
          <el-input v-model="querys[0].value" clearable placeholder="请输入车牌号" />
        </el-form-item>
        <el-form-item label="标识名称">
          <el-input v-model="querys[1].value" clearable placeholder="请输入标识名称" />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
          <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
        </el-form-item>
      </el-form>
    </div> -->
    <div ref="contentPanel" class="bbsl-table-content">
      <el-table
        ref="multipleSelection"
        v-loading="loading"
        border
        highlight-current-row
        size="mini"
        :data="tableData"
        :style="{width: '100%'}"
        :max-height="tableMaxHeight"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange"
        height="350px"
      >
        <el-table-column type="index" width="55" label="序号" />
        <el-table-column prop="code" label="车牌号" show-overflow-tooltip />
        <el-table-column prop="name" label="标识名称" show-overflow-tooltip />
        <el-table-column prop="vehicleType" label="车辆类型" show-overflow-tooltip />
        <el-table-column prop="color" label="车辆颜色" show-overflow-tooltip />
        <el-table-column prop="area" label="行驶区域" show-overflow-tooltip />
        <el-table-column prop="updateTime" label="更新时间" sortable show-overflow-tooltip />

        <el-table-column align="right" width="120px" label="操作" :index="999">
          <template slot-scope="scope">
            <el-button
              size="mini"
              type="primary"
              circle
              icon="el-icon-map-location"
              @click="$refs.gisMapDrawer.setArea(scope.row)"
            />
          </template>
        </el-table-column>
      </el-table>
      <el-pagination
        ref="paginationPanel"
        align="right"
        background
        class="bbsl-pagination"
        :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="total"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
      />
    </div>
    <vechicle-manage-dialog ref="formModal" />
    <GisMapDrawer ref="gisMapDrawer" @confirm="mapConfirm" />
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import VehicleManage from '@/api/manager/duty/vehicleManage.js'
import VechicleManageDialog from '@/views/Manage/duty/components/VechicleManageDialog'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import GisMapDrawer from '@/views/Manage/components/GisMapDrawer.vue'

export default {
    name: 'VehicleManage',
    components: {
        VechicleManageDialog,
        GisMapDrawer
    },
    props: {
        licensePlate: {
            type: String,
            default: ''
        }
    },
    mixins: [TableMixin],
    data() {
        return {
            url: {
                delete: '/manager/duty/vehicle/'
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'code_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'name_',
                    relation: 'AND',
                    value: ''
                }
            ],
            StshowFormDias: false,
            fuelTypes: []
        }
    },
    watch: {
        licensePlate: {
            handler(newVal, oldVal) {
                this.querys[0].value = newVal
                this.loadData()
            },
            immediate: true
        }
    },
    created() {
        // this.fuelTypes = dictContracts.getDictItemsFromCache('cmgt_rylx')
    },
    mounted() {},
    methods: {
        // 重置
        clearQuerys() {
            this.querys[0].value = ''
            this.querys[1].value = ''
        },
        // 获取list
        loadData(page) {
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.loading = true
            this.tableData = []
            this.queryParam.querys = []
            if (this.querys[0].value) {
                this.queryParam.querys.push(this.querys[0])
            }
            if (this.querys[1].value) {
                this.queryParam.querys.push(this.querys[1])
            }
            VehicleManage.loadVehicle(this.queryParam, res => {
                console.log('-------------load-------------')
                // console.log(res, 'res')
                this.total = res.total
                this.tableData = res.rows
                this.$set(this.tableData)
                this.loading = false
            })
        },
        // 修改
        handleUpdate(row) {
            // console.log(row.id)
            // this.$refs.formModal.Update(row)
            this.$refs.gisMapDrawer.setArea(row)
        },

        closeStshowForm() {
            this.StshowFormDias = false
        },
        mapConfirm(val, row) {
            // console.log('=======val========', val)
            row.area = val.toString()
            this.loading = true
            VehicleManage.editVehicle(row, res => {
                this.loading = false
                if (res.state) {
                    this.$notify({
                        type: 'success',
                        message: '设置【' + row.name + '】的车辆行驶区域成功',
                        duration: 2000
                    })
                    this.loadData()
                } else {
                    this.$message.warning(res.message)
                }
            })
        }
    }
}
</script>
<style lang="scss" scoped>
.type-tag {
    margin: 0 2px;
}
::v-deep .bbsl-pagination {
  position: static;
  margin: 8px 0 0 0;
}
</style>
